==> OB-3.1.2.tar.gz: OB-3.1.2/config/acconfig.h <==
/***********************************************************************
 *
 * Copyright (c) 1998
 * Object-Oriented Concepts, Inc.
 * Billerica, MA, USA
 *
 * Copyright (c) 1998
 * Object-Oriented Concepts GmbH
 * Ettlingen, Germany
 *
 * All Rights Reserved
 *
 ***********************************************************************/

@TOP@

/* Define if your c++ compiler doesn't know mutable. */
#undef HAVE_NO_MUTABLE

/* Define if your c++ compiler doesn't have namespaces. */
#undef HAVE_NO_NAMESPACE

/* Define if your c++ compiler supports the namespace std. */
#undef HAVE_STD_NAMESPACE

/* Define if your c++ compiler can explicitly instanciate templates. */
#undef HAVE_NO_EXPLICIT_TEMPLATES

/* Define if your c++ compiler does not have RTTI. */
#undef HAVE_NO_RTTI

/* Define if your c++ compiler can't overload const type conversions. */
#undef HAVE_NO_CONST_TYPE_CONVERSION_OVERLOAD

/* Define if your c++ compiler doesn't have typename. */
#undef HAVE_NO_TYPENAME

/* Define if you don't have a prototype for gethostname(). */
#undef HAVE_NO_GETHOSTNAME_PROTOTYPE

/* Define if there is no declaration for h_errno */
#undef HAVE_NO_H_ERRNO_DECLARATION

/* Define if accept() requires address length of type size_t. */
#undef HAVE_ACCEPT_WITH_SIZE_T

/* Define if getsockname() requires address length of type size_t. */
#undef HAVE_GETSOCKNAME_WITH_SIZE_T

/* Define if getsockopt() requires address length of type size_t. */
#undef HAVE_GETSOCKOPT_WITH_SIZE_T

/* Define if OS supports MIT threads. */
#undef HAVE_MIT_THREADS

/* Define if OS supports FSU threads. */
#undef HAVE_FSU_THREADS

/* Define if OS supports posix threads. */
#undef HAVE_POSIX_THREADS

/* Define if OS supports DCE threads. */
#undef HAVE_DCE_THREADS

/* Define if OS supports pthread_attr_setstacksize. */
#undef HAVE_PTHREAD_ATTR_SETSTACKSIZE

/* Define if OS supports pthread_delay_np. */
#undef HAVE_PTHREAD_DELAY_NP

/* Define if OS supports pthread_sched_yield. */
#undef HAVE_SCHED_YIELD

/* Define if OS supports pthread_yield. */
#undef HAVE_PTHREAD_YIELD

/* Define if JThreads/C++ is available. */
#undef HAVE_JTC

/* Define if JThreads/C++ has support for stop/suspend/resume. */
#undef HAVE_JTC_STOP

==> OB-4.0a2.tar.gz: OB-4.0a2/config/acconfig.h <==
/***********************************************************************
 *
 * Copyright (c) 1998
 * Object-Oriented Concepts, Inc.
 * Billerica, MA, USA
 *
 * Copyright (c) 1998
 * Object-Oriented Concepts GmbH
 * Ettlingen, Germany
 *
 * All Rights Reserved
 *
 ***********************************************************************/

@TOP@

/* Define if your c++ compiler doesn't have set_unexpected. */
#undef HAVE_NO_SET_UNEXPECTED

/* Define if your c++ compiler doesn't know mutable. */
#undef HAVE_NO_MUTABLE

/* Define if your c++ compiler supports iostream in namespace std. */
#undef HAVE_STD_IOSTREAM

/* Define if your c++ compiler supports STL in namespace std. */
#undef HAVE_STD_STL

/* Define if your c++ compiler can explicitly instanciate templates. */
#undef HAVE_NO_EXPLICIT_TEMPLATES

/* Define if your c++ compiler can't overload const type conversions. */
#undef HAVE_NO_CONST_TYPE_CONVERSION_OVERLOAD

/* Define if your c++ compiler doesn't have typename. */
#undef HAVE_NO_TYPENAME

/* Define if you don't have a prototype for gethostname(). */
#undef HAVE_NO_GETHOSTNAME_PROTOTYPE

/* Define if there is no declaration for h_errno */
#undef HAVE_NO_H_ERRNO_DECLARATION

/* Define if accept() requires address length of type size_t. */
#undef HAVE_ACCEPT_WITH_SIZE_T

/* Define if getsockname() requires address length of type size_t. */
#undef HAVE_GETSOCKNAME_WITH_SIZE_T

/* Define if getsockopt() requires address length of type size_t. */
#undef HAVE_GETSOCKOPT_WITH_SIZE_T

/* Define if OS supports MIT threads. */
#undef HAVE_MIT_THREADS

/* Define if OS supports FSU threads. */
#undef HAVE_FSU_THREADS

/* Define if OS supports posix threads. */
#undef HAVE_POSIX_THREADS

/* Define if OS supports DCE threads. */
#undef HAVE_DCE_THREADS

/* Define if OS supports pthread_attr_setstacksize. */
#undef HAVE_PTHREAD_ATTR_SETSTACKSIZE

/* Define if OS supports pthread_delay_np. */
#undef HAVE_PTHREAD_DELAY_NP

/* Define if OS supports pthread_sched_yield. */
#undef HAVE_SCHED_YIELD

/* Define if OS supports pthread_yield. */
#undef HAVE_PTHREAD_YIELD

/* Define if JThreads/C++ is available. */
#undef HAVE_JTC

/* Define if JThreads/C++ has support for stop/suspend/resume. */
#undef HAVE_JTC_STOP
